@@ -1,7 +1,7 @@
 filter.site<-function(data,site)
 {
   if(!is.data.frame(data) || !is.character(site) || !grepl("^[a-zA-Z]+$",gsub(" ", "", site)))
-     stop("invalid input parameter(s) specification")
+     stop("invalid input parameter(s) specification: check data/site")
   
   data(vmdbsite,envir=environment())
   vmdbsite<-get("vmdbsite",envir=environment())
